@@ -128,7 +128,7 @@ namespace libint2 {
        *         <li> specified by LIBINT_DATA_PATH environmental variable, if defined </li>
        *         <li> specified by DATADIR macro variable, if defined </li>
        *         <li> specified by SRCDATADIR macro variable, if defined </li>
-       *         <li> hardwired to directory \c /usr/share/libint/2.9.0/basis </li>
+       *         <li> hardwired to directory \c /usr/share/libint/2.11.0/basis </li>
        *       </ol>
        */
       BasisSet(std::string name,
@@ -404,7 +404,7 @@ namespace libint2 {
        *         <li> specified by LIBINT_DATA_PATH environmental variable, if defined </li>
        *         <li> specified by DATADIR macro variable, if defined </li>
        *         <li> specified by SRCDATADIR macro variable, if defined </li>
-       *         <li> hardwired to directory \c /usr/share/libint/2.9.0/basis </li>
+       *         <li> hardwired to directory \c /usr/share/libint/2.11.0/basis </li>
        *       </ol>
        *  @throw std::system_error if the path is not valid, or cannot be determined
        *  @return valid path to the data directory
@@ -421,7 +421,7 @@ namespace libint2 {
 #elif defined(SRCDATADIR)
           path = std::string{SRCDATADIR};
 #else
-          path = std::string("/usr/share/libint/2.9.0");
+          path = std::string("/usr/share/libint/2.11.0");
 #endif
         }
         // validate basis_path = path + "/basis"
@@ -481,7 +481,7 @@ namespace libint2 {
                                                                             ) {
 
         std::locale locale(locale_name.c_str());  // TODO omit c_str() with up-to-date stdlib
-        std::vector<std::vector<libint2::Shell>> ref_shells(118); // 118 = number of chemical elements
+        std::vector<std::vector<libint2::Shell>> ref_shells(119); // 118 = number of chemical elements + 1 because we insert at(Z)
         std::ifstream is(file_dot_g94);
         is.imbue(locale);
 
@@ -620,15 +620,15 @@ namespace libint2 {
         return ref_shells;
       }
 
-      DEPRECATED static size_t nbf(const std::vector<libint2::Shell>& shells) {
+      LIBINT2_DEPRECATED static size_t nbf(const std::vector<libint2::Shell>& shells) {
         return libint2::nbf(shells);
       }
 
-      DEPRECATED static size_t max_nprim(const std::vector<libint2::Shell>& shells) {
+      LIBINT2_DEPRECATED static size_t max_nprim(const std::vector<libint2::Shell>& shells) {
         return libint2::max_nprim(shells);
       }
 
-      DEPRECATED static int max_l(const std::vector<libint2::Shell>& shells) {
+      LIBINT2_DEPRECATED static int max_l(const std::vector<libint2::Shell>& shells) {
         return libint2::max_l(shells);
       }
 
